@@ -6,9 +6,9 @@
 
 #undef PACKAGE
 #undef VERSION
-#undef USE_GTK2
+#undef USE_CODEC
+#undef USE_THREAD
 
 #undef VMAID_BUILD_ENVIRONMENT
 
 #undef HAVE_I386_SET_LDT
-#undef USE_CODEC
