@@ -17,7 +17,6 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include "avibase.h"
-#include "misc/fileio.h"
 
 
 /******************************************************************************
@@ -57,7 +56,7 @@ avi_delete (AviEdit    *avi_edit,
         avi_edit->buf[i].pos -= samples_n;
       }
   for (i = 0; i < AVI_EDIT_CACHE; i++)
-    if (avi_edit->buf[i].data != NULL)
+    if (avi_edit->buf[i].data)
       avi_edit->buf[j++] = avi_edit->buf[i];
   while (j < AVI_EDIT_CACHE)
     avi_edit->buf[j++].data = NULL;
@@ -67,7 +66,7 @@ avi_delete (AviEdit    *avi_edit,
   if (start + samples_n < avi_length (avi_edit))
     {
       /* ja:削除する位置で分割する */
-      avi_split_file (avi_edit,start + samples_n);
+      avi_split_file (avi_edit, start + samples_n);
       q = avi_edit->file;
     }
   else
@@ -208,16 +207,6 @@ avi_paste (AviEdit    *avi_dst,
   if (!avi_dst || !avi_src || avi_type (avi_dst) != avi_type (avi_src)
                                     || pos < 0 || avi_length (avi_dst) < pos)
     return FALSE;
-  if (avi_type (avi_dst) == AVI_STREAM_AUDIO)
-    {
-      gint length;
-
-      /* ja:オーディオ */
-      length = wf_header_bytes (avi_dst->wfx);
-      if (length != wf_header_bytes (avi_src->wfx)
-                            || g_memcmp (avi_dst->wfx, avi_src->wfx, length))
-        return FALSE;/* ja:フォーマットが異なる */
-    }
   /* ja:キャッシュ */
   for (i = 0; i < AVI_EDIT_CACHE && avi_dst->buf[i].data; i++)
     if (pos <= avi_dst->buf[i].pos)
@@ -225,7 +214,7 @@ avi_paste (AviEdit    *avi_dst,
   if (pos < avi_length (avi_dst))
     {
       /* ja:貼り付ける位置で分割する */
-      avi_split_file (avi_dst,pos);
+      avi_split_file (avi_dst, pos);
       p = avi_dst->file->prev;
       q = avi_dst->file;
     }
@@ -245,7 +234,7 @@ avi_paste (AviEdit    *avi_dst,
     avi_src->file = avi_src->file->prev;
   avi_src->file->prev = p;
   if (p)
-    p->next=avi_src->file;
+    p->next = avi_src->file;
   /* ja:末尾へ移動する */
   while (avi_src->file->next)
     avi_src->file = avi_src->file->next;
@@ -264,7 +253,8 @@ avi_paste (AviEdit    *avi_dst,
   g_free (avi_src->wfx);
   g_free (avi_src);
   /* ja:最適化 */
-  if (p && p->name && p->next->name && g_strcmp (p->name, p->next->name) == 0
+  if (p && p->name && p->next->name
+                                && g_strfilecmp (p->name, p->next->name) == 0
                                     && p->start + p->length == p->next->start)
     {
       p->length += p->next->length;
@@ -275,12 +265,13 @@ avi_paste (AviEdit    *avi_dst,
           avi_dst->offset -= avi_dst->file->length;
         }
       if (p->prev)
-        p->prev->next=p->next;
+        p->prev->next = p->next;
       if (p->next)
-        p->next->prev=p->prev;
+        p->next->prev = p->prev;
       avi_release_file (p);
     }
-  if (q && q->name && q->prev->name && g_strcmp (q->name, q->prev->name) == 0
+  if (q && q->name && q->prev->name
+                                && g_strfilecmp (q->name, q->prev->name) == 0
                             && q->prev->start + q->prev->length == q->start)
     {
       if (avi_dst->file == q)
