@@ -16,6 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
+#include "avibase.h"
 #include "avifileextra.h"
 
 
@@ -36,7 +37,7 @@ avi_file_extra_get_type (void)
 
   if (!file_extra_type)
     {
-      static const GTypeInfo fileextra_info =
+      const static GTypeInfo fileextra_info =
       {
         sizeof (AviFileExtraClass),
         NULL,               /* base_init */
@@ -96,7 +97,7 @@ avi_file_extra_init (AviFileExtra *fileextra)
 ******************************************************************************/
 /*  ja:新規作成
     RET,ウィジェット                                                        */
-GtkWidget*
+GtkWidget *
 avi_file_extra_new (void)
 {
   return GTK_WIDGET (g_object_new (AVI_TYPE_FILE_EXTRA, NULL));
@@ -222,7 +223,7 @@ avi_file_extra_toggled_video (GtkWidget    *widget,
 {
   gint max;
 
-  max = (gint) g_object_get_data (G_OBJECT (widget), "user_data");
+  max = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "user_data"));
   gtk_spin_button_set_range (GTK_SPIN_BUTTON (fileextra->spin0), 0, max);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (fileextra->spin0), 0);
   gtk_spin_button_set_range (GTK_SPIN_BUTTON (fileextra->spin1), 0, max);
@@ -244,7 +245,6 @@ avi_file_extra_changed (GtkWidget          *widget,
   GList *glist;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   IcmObject *icm_object = NULL;
-  IcmInfo icm_info;
 
 #if GTK_CHECK_VERSION(2,4,0)
   if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (avi_stream->combo), &iter))
@@ -294,8 +294,7 @@ avi_file_extra_changed (GtkWidget          *widget,
     }
   if (avi_stream->spin2)
     {
-      if (icm_object && icm_get_info (icm_object, &icm_info)
-                                    && (icm_info.flags & ICM_FLAG_CRUNCH) != 0)
+      if (icm_object && (icm_get_flags (icm_object) & ICM_FLAG_CRUNCH) != 0)
         {
           gtk_widget_set_sensitive (GTK_WIDGET (avi_stream->label2), TRUE);
           gtk_widget_set_sensitive (GTK_WIDGET (avi_stream->spin2), TRUE);
@@ -410,8 +409,8 @@ avi_file_extra_set_handle (AviFileExtra  *fileextra,
   for (streams = 0; avi_edit[streams]; streams++)
     switch (avi_type (avi_edit [streams]))
       {
-        case AVI_STREAM_VIDEO: video++; break;
-        case AVI_STREAM_AUDIO: audio++; break;
+        case AVI_TYPE_VIDEO: video++; break;
+        case AVI_TYPE_AUDIO: audio++; break;
         default: return;
       }
   if (streams <= 0)
@@ -459,7 +458,7 @@ avi_file_extra_set_handle (AviFileExtra  *fileextra,
           g_object_set_data (G_OBJECT (vbox), "user_data", avi_stream);
           g_signal_connect (G_OBJECT (vbox), "destroy",
                         G_CALLBACK (avi_file_extra_destroy_vbox), avi_stream);
-          if (avi_type (avi_edit[i]) == AVI_STREAM_VIDEO)
+          if (avi_type (avi_edit[i]) == AVI_TYPE_VIDEO)
             {
               gint j;
               GList *glist_object;      /* ja:IcmObjectのリスト */
@@ -472,15 +471,13 @@ avi_file_extra_set_handle (AviFileExtra  *fileextra,
               for (j = 0; j < length; j++)
                 {
                   IcmObject *icm_object;
-                  IcmInfo icm_info;
 
                   icm_object = icm_open
                                 ((guint32)g_list_nth_data (glist_handler, j),
                                 ICM_MODE_COMPRESS);
                   if (!icm_object)
                     continue;
-                  if (!icm_compress_query (icm_object, avi_edit[i]->bmih)
-                                    || !icm_get_info (icm_object, &icm_info))
+                  if (!icm_compress_query (icm_object, avi_edit[i]->bmih))
                     {
                       icm_close (icm_object);
                       continue;
@@ -492,12 +489,12 @@ avi_file_extra_set_handle (AviFileExtra  *fileextra,
                                 (gtk_adjustment_new (-1, -1, 10000, 1, 5, 0)),
                                  0, 0);
                   if (!avi_stream->spin1
-                        && icm_compress_get_default_key_frame(icm_object) > 0)
+                        && icm_compress_get_default_key_frame (icm_object) > 0)
                         avi_stream->spin1 = gtk_spin_button_new (GTK_ADJUSTMENT
                                 (gtk_adjustment_new (0, 0, G_MAXINT, 1, 5, 0)),
                                  0, 0);
                   if (!avi_stream->spin2
-                        && (icm_info.flags & ICM_FLAG_CRUNCH) != 0)
+                        && (icm_get_flags (icm_object) & ICM_FLAG_CRUNCH) != 0)
                         avi_stream->spin2 = gtk_spin_button_new (GTK_ADJUSTMENT
                                 (gtk_adjustment_new (0, 0, G_MAXINT, 1, 5, 0)),
                                  0, 0);
@@ -507,14 +504,15 @@ avi_file_extra_set_handle (AviFileExtra  *fileextra,
                       avi_stream->button = gtk_button_new_with_mnemonic
                                                         (_("Con_figure..."));
                   glist_object = g_list_append (glist_object, icm_object);
-                  glist_name = g_list_append (glist_name, icm_info.name);
+                  glist_name = g_list_append (glist_name,
+                                        (gpointer)icm_get_name (icm_object));
                 }
               if (g_list_length (glist_name) > 1)
                 {
 #if GTK_CHECK_VERSION(2,4,0)
                   GtkListStore *store;
-#else /* not GTK_CHECK_VERSION(2,4,0) */
-#endif /* not GTK_CHECK_VERSION(2,4,0) */
+                  GtkCellRenderer *renderer;
+#endif /* GTK_CHECK_VERSION(2,4,0) */
 
                   /* ja:チェックボタン */
                   avi_stream->check = gtk_check_button_new_with_mnemonic
@@ -526,9 +524,7 @@ avi_file_extra_set_handle (AviFileExtra  *fileextra,
 #if GTK_CHECK_VERSION(2,4,0)
                   store = gtk_list_store_new (2,
                                                 G_TYPE_STRING, G_TYPE_POINTER);
-                  avi_stream->combo = gtk_combo_box_new_with_model
-                                                    (GTK_TREE_MODEL (store));
-                  for (j = g_list_length (glist_name); j >= 0; j--)
+                  for (j = g_list_length (glist_name) - 1; j >= 0; j--)
                     {
                       GtkTreeIter iter;
 
@@ -537,6 +533,15 @@ avi_file_extra_set_handle (AviFileExtra  *fileextra,
                                     0, g_list_nth_data (glist_name, j),
                                     1, g_list_nth_data (glist_object, j), -1);
                     }
+                  avi_stream->combo = gtk_combo_box_new_with_model
+                                                    (GTK_TREE_MODEL (store));
+                  g_object_unref (store);
+                  renderer = gtk_cell_renderer_text_new ();
+                  gtk_cell_layout_pack_start
+                        (GTK_CELL_LAYOUT (avi_stream->combo), renderer, TRUE);
+                  gtk_cell_layout_set_attributes
+                                (GTK_CELL_LAYOUT (avi_stream->combo), renderer,
+                                                            "text", 0, NULL);
                   gtk_combo_box_set_active (GTK_COMBO_BOX (avi_stream->combo),
                                                                             0);
                   g_signal_connect (G_OBJECT (avi_stream->combo), "changed",
@@ -582,8 +587,6 @@ avi_file_extra_set_handle (AviFileExtra  *fileextra,
                   label0 = gtk_label_new ((const gchar *)
                                               g_list_nth_data (glist_name, 0));
                 }
-              for (j = g_list_length (glist_name) - 1; j >= 0; j--)
-                g_free (g_list_nth_data (glist_name, j));
               g_list_free (glist_object);
               g_list_free (glist_name);
               if (avi_stream->spin0)
@@ -681,7 +684,7 @@ avi_file_extra_set_handle (AviFileExtra  *fileextra,
                     gtk_box_pack_start (GTK_BOX (hbox0),
                                         avi_stream->check, TRUE, TRUE, 0);
                   if (avi_stream->button)
-                    gtk_box_pack_end(GTK_BOX(hbox0),
+                    gtk_box_pack_end (GTK_BOX (hbox0),
                                         avi_stream->button, FALSE, FALSE, 0);
                   gtk_box_pack_end (GTK_BOX (vbox), hbox0, FALSE, FALSE, 0);
                 }
@@ -695,25 +698,25 @@ avi_file_extra_set_handle (AviFileExtra  *fileextra,
             }
           text = avi_get_name (avi_edit[i])
                                 ? g_strdup (avi_get_name (avi_edit[i]))
-                                : avi_type (avi_edit[i]) == AVI_STREAM_VIDEO
+                                : avi_type (avi_edit[i]) == AVI_TYPE_VIDEO
                                         ? g_strdup_printf ("Video #%d", video)
                                         : g_strdup_printf ("Audio #%d", audio);
           if (GTK_IS_NOTEBOOK (fileextra->notebook))
             {
               GtkWidget *radio;
 
-              if (avi_type (avi_edit[i]) == AVI_STREAM_VIDEO
+              if (avi_type (avi_edit[i]) == AVI_TYPE_VIDEO
                                                     && fileextra->video > 1)
                 {
                   radio = gtk_radio_button_new_with_label (gslist_v, text);
                   g_object_set_data (G_OBJECT (radio), "user_data",
-                                    (gpointer)(avi_length (avi_edit[i]) - 1));
-                  g_signal_connect (G_OBJECT(radio), "toggled",
+                            GINT_TO_POINTER (avi_length (avi_edit[i]) - 1));
+                  g_signal_connect (G_OBJECT (radio), "toggled",
                                     G_CALLBACK (avi_file_extra_toggled_video),
                                     fileextra);
                   gslist_v = gtk_radio_button_group (GTK_RADIO_BUTTON (radio));
                 }
-              else if (avi_type (avi_edit[i]) == AVI_STREAM_AUDIO
+              else if (avi_type (avi_edit[i]) == AVI_TYPE_AUDIO
                                                     && fileextra->audio > 1)
                 {
                   radio = gtk_radio_button_new_with_label (gslist_a, text);
@@ -751,7 +754,7 @@ avi_file_extra_set_handle (AviFileExtra  *fileextra,
       gslist = gtk_radio_button_group (GTK_RADIO_BUTTON (fileextra->radio1));
       /* ja:スピンボタン */
       for (i = 0; i < streams; i++)
-        if (avi_type (avi_edit[i]) == AVI_STREAM_VIDEO)
+        if (avi_type (avi_edit[i]) == AVI_TYPE_VIDEO)
           break;
       fileextra->spin0 = gtk_spin_button_new (GTK_ADJUSTMENT
             (gtk_adjustment_new (0, 0, avi_length (avi_edit[i]) - 1, 1, 5, 0)),
@@ -836,15 +839,14 @@ avi_file_extra_set_handle (AviFileExtra  *fileextra,
 /*  ja:保存用のオプションを取得する
     fileextra,ウィジェット
         RET,オプション,NULL:エラー                                          */
-AviSave*
+AviSave *
 avi_file_extra_get_option (AviFileExtra *fileextra)
 {
-  gint i, streams, value;
+  gint i, streams;
   GList *glist;
   GtkWidget *child, *radio;
   AviFileExtraStream *avi_stream;
   AviSave *avi_save;
-  IcmObject *icm_object;
 
   if (!fileextra)
     return NULL;
@@ -852,7 +854,7 @@ avi_file_extra_get_option (AviFileExtra *fileextra)
   if (fileextra->radio0
     && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (fileextra->radio0)))
     {
-      avi_save->type = AVI_TYPE_AVI;
+      avi_save->type = AVI_FILE_AVI;
       if (GTK_IS_NOTEBOOK (fileextra->notebook))
         {
           glist = gtk_container_children (GTK_CONTAINER (fileextra->notebook));
@@ -866,6 +868,8 @@ avi_file_extra_get_option (AviFileExtra *fileextra)
       avi_save->avi_opt = g_malloc0 ((streams + 1) * sizeof (AviOptions));
       for (i = 0; i < streams; i++)
         {
+          IcmObject *icm_object;
+
           if (GTK_IS_NOTEBOOK (fileextra->notebook))
             {
               child = gtk_notebook_get_nth_page
@@ -880,15 +884,15 @@ avi_file_extra_get_option (AviFileExtra *fileextra)
           if (avi_stream->combo && (icm_object = g_object_get_data
                                 (G_OBJECT (avi_stream->combo), "user_data")))
             {
-              avi_save->avi_opt[i].handler = icm_get_handler(icm_object);
-              avi_save->avi_opt[i].key_frame = avi_stream->spin0
+              avi_save->avi_opt[i].handler = icm_get_handler (icm_object);
+              avi_save->avi_opt[i].quality = avi_stream->spin0
                                 && GTK_WIDGET_IS_SENSITIVE (avi_stream->spin0)
                                     ? gtk_spin_button_get_value_as_int
-                                    (GTK_SPIN_BUTTON (avi_stream->spin0)) : 0;
-              avi_save->avi_opt[i].quality = avi_stream->spin1
+                                    (GTK_SPIN_BUTTON (avi_stream->spin0)) : -1;
+              avi_save->avi_opt[i].key_frame = avi_stream->spin1
                                 && GTK_WIDGET_IS_SENSITIVE (avi_stream->spin1)
                                     ? gtk_spin_button_get_value_as_int
-                                    (GTK_SPIN_BUTTON (avi_stream->spin1)) : -1;
+                                    (GTK_SPIN_BUTTON (avi_stream->spin1)) : 0;
               avi_save->avi_opt[i].data_rate = avi_stream->spin2
                                 && GTK_WIDGET_IS_SENSITIVE (avi_stream->spin2)
                                     ? gtk_spin_button_get_value_as_int
@@ -923,13 +927,15 @@ avi_file_extra_get_option (AviFileExtra *fileextra)
   else if (fileextra->radio1
     && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (fileextra->radio1)))
     {
-      avi_save->type = AVI_TYPE_BITMAP;
+      avi_save->type = AVI_FILE_BITMAP;
       avi_save->start = gtk_spin_button_get_value_as_int
                                         (GTK_SPIN_BUTTON (fileextra->spin0));
       avi_save->end = gtk_spin_button_get_value_as_int
                                         (GTK_SPIN_BUTTON (fileextra->spin1));
       if (avi_save->start > avi_save->end)
         {
+          gint value;
+
           value = avi_save->start;
           avi_save->start = avi_save->end;
           avi_save->end = value;
@@ -946,7 +952,7 @@ avi_file_extra_get_option (AviFileExtra *fileextra)
               radio = gtk_notebook_get_tab_label
                                 (GTK_NOTEBOOK (fileextra->notebook), child);
               avi_stream = g_object_get_data (G_OBJECT (child), "user_data");
-              if (avi_type (avi_stream->avi_edit) == AVI_STREAM_VIDEO
+              if (avi_type (avi_stream->avi_edit) == AVI_TYPE_VIDEO
                 && (!GTK_IS_RADIO_BUTTON (radio)
                 || gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio))))
                 break;
@@ -957,7 +963,7 @@ avi_file_extra_get_option (AviFileExtra *fileextra)
   else if (fileextra->radio2
     && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (fileextra->radio2)))
     {
-      avi_save->type = AVI_TYPE_WAVE;
+      avi_save->type = AVI_FILE_WAVE;
       if (GTK_IS_NOTEBOOK (fileextra->notebook))
         {
           glist = gtk_container_children (GTK_CONTAINER (fileextra->notebook));
@@ -970,7 +976,7 @@ avi_file_extra_get_option (AviFileExtra *fileextra)
               radio = gtk_notebook_get_tab_label
                                 (GTK_NOTEBOOK (fileextra->notebook), child);
               avi_stream = g_object_get_data (G_OBJECT (child), "user_data");
-              if (avi_type (avi_stream->avi_edit) == AVI_STREAM_AUDIO
+              if (avi_type (avi_stream->avi_edit) == AVI_TYPE_AUDIO
                 && (!GTK_IS_RADIO_BUTTON (radio)
                 || gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio))))
                 break;
@@ -981,7 +987,7 @@ avi_file_extra_get_option (AviFileExtra *fileextra)
   else if (fileextra->radio3
     && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (fileextra->radio3)))
     {
-      avi_save->type = AVI_TYPE_SCENARIO;
+      avi_save->type = AVI_FILE_SCENARIO;
     }
   else
     {
