@@ -18,7 +18,17 @@
 */
 #include "avibase.h"
 #include "avifmt.h"
-#include "misc/fileio.h"
+
+
+struct _AviFrame
+{
+  guint32 handler;              /* ja:4文字コード */
+  gint pos;                     /* ja:最後に取得したフレーム */
+  AviEdit *avi_edit;
+  IcmObject *icm_object;        /* ja:ICM展開 */
+  BitmapInfoHeader *bmih;       /* ja:展開後のフォーマット */
+  gsize bmih_size;              /* ja:展開後のフォーマットのサイズ */
+};
 
 
 /******************************************************************************
@@ -34,13 +44,11 @@ avi_get_frame_open (AviEdit *avi_edit)
 {
   AviFrame *avi_frame;
 
-  if (!avi_edit || avi_type (avi_edit) != AVI_STREAM_VIDEO)
+  if (!avi_edit || avi_type (avi_edit) != AVI_TYPE_VIDEO)
     return NULL;
-  avi_frame = g_malloc (sizeof (AviFrame));
-  avi_frame->handler = 0;
+  avi_frame = g_malloc0 (sizeof (AviFrame));
   avi_frame->pos = -1;
   avi_frame->avi_edit = avi_edit;
-  avi_frame->icm_object = NULL;
   return avi_frame;
 }
 
@@ -58,6 +66,7 @@ avi_get_frame_close (AviFrame *avi_frame)
       icm_decompress_end (avi_frame->icm_object);
       icm_close (avi_frame->icm_object);
     }
+  g_free (avi_frame->bmih);
   g_free (avi_frame);
   return TRUE;
 }
@@ -79,7 +88,7 @@ avi_get_frame_real (AviFrame   *avi_frame,
   avi_edit = avi_frame->avi_edit;
   if (pos < 0 || avi_length (avi_edit) <= pos)
     return NULL;                    /* ja:範囲外 */
-  avi_get_file (avi_edit,pos);      /* ja:AVIファイルを求める */
+  avi_get_file (avi_edit, pos);     /* ja:AVIファイルを求める */
   if (avi_edit->file->handler == AVI_STREAM_COMP_DIB)
     {
       /* ja:ヌルフレームのチェック */
@@ -124,6 +133,9 @@ avi_get_frame_real (AviFrame   *avi_frame,
             {
               icm_decompress_end (avi_frame->icm_object);
               icm_close (avi_frame->icm_object);
+              g_free (avi_frame->bmih);
+              avi_frame->bmih = NULL;
+              avi_frame->bmih_size = 0;
             }
           avi_frame->handler = avi_edit->file->handler;
           avi_frame->pos = -1;
@@ -140,6 +152,25 @@ avi_get_frame_real (AviFrame   *avi_frame,
               icm_close (avi_frame->icm_object);
               avi_frame->handler = 0;
               avi_frame->icm_object = NULL;
+              g_free (avi_frame->bmih);
+              avi_frame->bmih = NULL;
+              avi_frame->bmih_size = 0;
+              return NULL;
+            }
+          avi_frame->bmih_size = icm_decompress_get_format_size
+                                                        (avi_frame->icm_object,
+                                                        avi_edit->file->bmih);
+          avi_frame->bmih = g_malloc (avi_frame->bmih_size);
+          if (avi_frame->bmih_size <= 0 || !avi_frame->bmih
+                        || !icm_decompress_get_format (avi_frame->icm_object,
+                                        avi_edit->file->bmih, avi_frame->bmih))
+            {
+              icm_close (avi_frame->icm_object);
+              avi_frame->handler = 0;
+              avi_frame->icm_object = NULL;
+              g_free (avi_frame->bmih);
+              avi_frame->bmih = NULL;
+              avi_frame->bmih_size = 0;
               return NULL;
             }
         }
@@ -147,22 +178,15 @@ avi_get_frame_real (AviFrame   *avi_frame,
       /* ja:非キーフレームのチェック */
       i = j = pos - avi_edit->offset + avi_edit->file->start;
       if (avi_frame->pos != pos - 1 || pos <= avi_edit->offset)
-        while (j>0)
+        while (j > 0)
           { /* ja:連続していないとき */
             if ((avi_edit->file->index[j].flags & AVI_IF_KEYFRAME)
                                         && avi_edit->file->index[j].size > 0)
               break;
             j--;
           }
-      bmih = g_malloc (icm_decompress_get_format_size (avi_frame->icm_object,
-                                                        avi_edit->file->bmih));
-      if (!icm_decompress_get_format (avi_frame->icm_object,
-                                                    avi_edit->file->bmih,bmih))
-        {
-          g_free (bmih);
-          return NULL;
-        }
-      bmih = g_realloc (bmih, bm_all_bytes (bmih));
+      bmih = g_malloc (bm_all_bytes (avi_frame->bmih));
+      g_memmove (bmih, avi_frame->bmih, avi_frame->bmih_size);
       output = (guint8 *)bmih + bm_header_bytes (bmih);
       while (j <= i)
         {
@@ -385,7 +409,7 @@ gboolean
 avi_is_keyframe (AviEdit    *avi_edit,
                  const gint  pos)
 {
-  if (avi_edit && avi_type (avi_edit) == AVI_STREAM_VIDEO)
+  if (avi_edit && avi_type (avi_edit) == AVI_TYPE_VIDEO)
     {
       /* ja:ビデオ */
       avi_get_file (avi_edit, pos);/* ja:AVIファイルを求める */
