@@ -24,7 +24,7 @@
 * ja:ビットマップ加工関数                                                     *
 *                                                                             *
 ******************************************************************************/
-typedef struct
+typedef struct _PaletteTableList
 {
   gint blue_min, blue_max, green_min, green_max, red_min, red_max;
   guint count;
