@@ -25,7 +25,7 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif
+#endif /* __cplusplus */
 
 
 #define BI_COMP_RGB         0
@@ -42,7 +42,7 @@ extern "C" {
 #ifdef USE_GCC
 
 
-typedef struct BitmapFileHeader_Tag
+typedef struct _BitmapFileHeader
 {
   guint16 type __attribute__((packed));
   guint32 size __attribute__((packed));
@@ -52,7 +52,7 @@ typedef struct BitmapFileHeader_Tag
 } BitmapFileHeader;
 
 
-typedef struct BitmapInfoHeader_Tag
+typedef struct _BitmapInfoHeader
 {
   guint32 size __attribute__((packed));
   gint32 width __attribute__((packed));
@@ -68,7 +68,7 @@ typedef struct BitmapInfoHeader_Tag
 } BitmapInfoHeader;
 
 
-typedef struct RgbQuad_Tag
+typedef struct _RgbQuad
 {
   guint8 blue __attribute__((packed));
   guint8 green __attribute__((packed));
@@ -80,9 +80,9 @@ typedef struct RgbQuad_Tag
 #else /* not USE_GCC */
 
 
-typedef struct { guint8 dummy[BMFH_SIZE]; } BitmapFileHeader;
-typedef struct { guint8 dummy[BMIH_SIZE]; } BitmapInfoHeader;
-typedef struct { guint8 dummy[RGBQUAD_SIZE]; } RgbQuad;
+typedef struct _BitmapFileHeader { guint8 dummy[BMFH_SIZE]; } BitmapFileHeader;
+typedef struct _BitmapInfoHeader { guint8 dummy[BMIH_SIZE]; } BitmapInfoHeader;
+typedef struct _RgbQuad { guint8 dummy[RGBQUAD_SIZE]; } RgbQuad;
 
 
 #endif /* not USE_GCC */
@@ -489,7 +489,7 @@ bitmap_overlay_32 (BitmapInfoHeader *bmih0,
 
 #ifdef __cplusplus
 }
-#endif
+#endif /* __cplusplus */
 
 
-#endif
+#endif /* __BITMAP_H__ */
