@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,17 +26,17 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif
+#endif /* __cplusplus */
 
 
-typedef struct ChunkList_Tag
+typedef struct _ChunkList
 {
   goffset offset;               /* ja:オフセット */
   guint32 id;                   /* ja:ID */
   guint32 size;                 /* ja:サイズ */
   guint32 form;                 /* ja:フォームタイプ */
 } ChunkList;
-typedef struct Chunk_Tag
+typedef struct _Chunk
 {
   gint num;                     /* ja:リストの数 */
   ChunkList *list;
@@ -175,7 +175,7 @@ chunk_form (FileIO *fio);
 
 #ifdef __cplusplus
 }
-#endif
+#endif /* __cplusplus */
 
 
-#endif
+#endif /* __CHUNK_H__ */
