@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1999-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif
+#endif /* __cplusplus */
 
 
 #define WAVE_FORMAT_PCM 1
@@ -37,7 +37,7 @@ extern "C" {
 #ifdef USE_GCC
 
 
-typedef struct WaveFormatEx_Tag
+typedef struct _WaveFormatEx
 {
   guint16 format_tag __attribute__((packed));
   guint16 channels __attribute__((packed));
@@ -52,12 +52,15 @@ typedef struct WaveFormatEx_Tag
 #else /* not USE_GCC */
 
 
-typedef struct { guint8 dummy[WFX_SIZE]; } WaveFormatEx;
+typedef struct _WaveFormatEx { guint8 dummy[WFX_SIZE]; } WaveFormatEx;
 
 
 #endif /* not USE_GCC */
 
 
+typedef struct _WaveConv WaveConv;
+
+
 /******************************************************************************
 *                                                                             *
 * ja:Wave構造体マクロ                                                         *
@@ -101,9 +104,66 @@ typedef struct { guint8 dummy[WFX_SIZE]; } WaveFormatEx;
 #define wf_header_bytes(wfx) (wfx_get_size(wfx)+WFX_SIZE)
 
 
+/******************************************************************************
+*                                                                             *
+* ja:PCM加工関数                                                              *
+*                                                                             *
+******************************************************************************/
+/*  ja:PCMの変換を開始する
+    wfx0,元のWaveFormatEx構造体へのポインタ
+    wfx1,新しいWaveFormatEx構造体へのポインタ
+     RET,変換ハンドル,NULL:変換不可能                                       */
+WaveConv *
+wave_convert_begin (WaveFormatEx *wfx0,
+                    WaveFormatEx *wfx1);
+
+
+/*  ja:PCMの変換をする
+            wcv,変換ハンドル
+         in_buf,入力データ
+     in_samples,入力データのサンプル数
+        out_buf,出力データ
+    out_samples,出力データのサンプル数
+            RET,TRUE:正常終了,FALSE:エラー                                  */
+gboolean
+wave_convert (WaveConv      *wcv,
+              gpointer       in_buf,
+              const gint     in_samples,
+              gpointer      *out_buf,
+              gint          *out_samples);
+
+
+/*  ja:PCMの変換を終了する
+      wave_conv,変換ハンドル
+        out_buf,出力データ
+    out_samples,出力データのサンプル数
+            RET,TRUE:正常終了,FALSE:エラー                                  */
+gboolean
+wave_convert_end (WaveConv *wcv,
+                  gpointer *out_buf,
+                  gint     *out_samples);
+
+
+/*  ja:PCMの変換をする
+           wfx0,元のWaveFormatEx構造体へのポインタ
+           wfx1,新しいWaveFormatEx構造体へのポインタ
+         in_buf,入力データ
+     in_samples,入力データのサンプル数
+        out_buf,出力データ
+    out_samples,出力データのサンプル数
+            RET,TRUE:正常終了,FALSE:エラー                                  */
+gboolean
+wave_convert_direct (WaveFormatEx  *wfx0,
+                     WaveFormatEx  *wfx1,
+                     gpointer       in_buf,
+                     const gint     in_samples,
+                     gpointer      *out_buf,
+                     gint          *out_samples);
+
+
 #ifdef __cplusplus
 }
-#endif
+#endif /* __cplusplus */
 
 
-#endif
+#endif /* __WAVE_H__ */
