@@ -23,8 +23,8 @@
 #include "thread.h"
 #include "misc/fileio.h"
 #include "misc/misc.h"
-#include "misc/misc_history.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzhistory.h"
+#include "orz/orzmdi.h"
 
 
 /******************************************************************************
@@ -49,13 +49,13 @@ file_open_avi (AviEdit     *avi_edit[],
     if ((avi_edit_tmp = avi_open (file, i)))
       switch (avi_type (avi_edit_tmp))
         {
-          case AVI_STREAM_VIDEO:
+          case AVI_TYPE_VIDEO:
             if (!avi_edit[0])
               avi_edit[0] = avi_edit_tmp;
             else
               avi_release (avi_edit_tmp);
               break;
-          case AVI_STREAM_AUDIO:
+          case AVI_TYPE_AUDIO:
             if (!avi_edit[1])
               avi_edit[1] = avi_edit_tmp;
             else
@@ -231,7 +231,7 @@ file_open_edit (FileOpen *file_open)
             }
         }
       if (!vmaid->avi_edit[0] && !vmaid->avi_edit[1]
-                    && avi_file_type (file_open->file) == AVI_TYPE_SCENARIO)
+                    && avi_file_type (file_open->file) == AVI_FILE_SCENARIO)
         {
           gchar *scenario = NULL;
           goffset offset;
@@ -277,17 +277,18 @@ file_open_edit (FileOpen *file_open)
               g_free (vmaid);
               return 0;
             }
-          if ((avi_edit = avi_from_scenario (scenario)))
+          avi_edit = avi_from_scenario (scenario);
+          if (avi_edit)
             for (i = 0; avi_edit[i]; i++)
               switch (avi_type (avi_edit[i]))
                 {
-                  case AVI_STREAM_VIDEO:
+                  case AVI_TYPE_VIDEO:
                     if (!vmaid->avi_edit[0])
                       vmaid->avi_edit[0] = avi_edit[i];
                     else
                       avi_release (avi_edit[i]);
                     break;
-                  case AVI_STREAM_AUDIO:
+                  case AVI_TYPE_AUDIO:
                     if (!vmaid->avi_edit[1])
                       vmaid->avi_edit[1] = avi_edit[i];
                     else
@@ -326,7 +327,7 @@ file_open_edit (FileOpen *file_open)
     vmaid->cursor.stream = 1;
 
 #ifdef USE_THREAD
-  gdk_threads_enter();
+  gdk_threads_enter ();
 #endif /* USE_THREAD */
 
   /* ja:表示エリア */
@@ -372,7 +373,7 @@ file_open_edit (FileOpen *file_open)
   gtk_box_pack_start (GTK_BOX (vbox), vmaid->hscroll, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (xbox), vbox, FALSE, FALSE,0);
   /* ja:表示 */
-  page_num = misc_mdi_append_page (MISC_MDI (mdi),
+  page_num = orz_mdi_append_page (ORZ_MDI (mdi),
                         xbox, filename, !file_open || !file_open->file, vmaid);
   gtk_widget_show_all (xbox);
   gtk_notebook_set_page (GTK_NOTEBOOK (mdi), page_num);
@@ -380,10 +381,10 @@ file_open_edit (FileOpen *file_open)
 
   /* ja:新規作成ではなく、ファイルが存在する時には履歴に加える */
   if (file_open && fileio_isfile (file_open->file))
-    misc_history_add_file (MISC_HISTORY (history), file_open->file);
+    orz_history_add_file (ORZ_HISTORY (history), file_open->file);
 
 #ifdef USE_THREAD
-  gdk_threads_leave();
+  gdk_threads_leave ();
 #endif /* USE_THREAD */
 
   if (file_open)
