@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,61 +26,51 @@
 * ja:ジャンプダイアログ関数群                                                 *
 *                                                                             *
 ******************************************************************************/
-static gboolean jump_clicked_ok;
-static GtkWidget *dialog, *button0, *entry, *label;
-
-
-/* ja:OKボタンが押された */
-static void
-jump_dialog_clicked (GtkWidget  *widget,
-                     JumpDialog *jmp)
-{
-  misc_str_to_val (&jmp->frame,
-                            gtk_entry_get_text (GTK_ENTRY (entry)), 10, FALSE);
-  gtk_widget_destroy (dialog);
-  jump_clicked_ok = TRUE;
-}
-
-
 /* ja:エントリーでリターンが押された */
 static void
-jump_dialog_activate (GtkWidget  *widget,
-                      JumpDialog *jmp)
+jump_dialog_activate (GtkWidget *widget,
+                      GtkWidget *dialog)
 {
   gint value;
+  JumpConfig *jmpcfg;
 
-  if (misc_str_to_val (&value, 
+  jmpcfg = g_object_get_data (G_OBJECT (dialog), "user_data");
+  if (misc_str_to_val (&value,
                             gtk_entry_get_text (GTK_ENTRY (widget)), 10, FALSE)
-                                            && 0 <= value && value <= jmp->max)
-    jump_dialog_clicked (widget, jmp);
+            && jmpcfg->frame != value && 0 <= value && value <= jmpcfg->max)
+    gtk_dialog_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 }
 
 
 /* ja:エントリーが変更された */
 static void
-jump_dialog_changed (GtkWidget  *widget,
-                     JumpDialog *jmp)
+jump_dialog_changed (GtkWidget *widget,
+                     GtkWidget *dialog)
 {
-  gchar *text;
-  gint t, value;
+  gint value;
 
   if (misc_str_to_val (&value,
                         gtk_entry_get_text (GTK_ENTRY (widget)), 10, FALSE))
     {
-#ifdef G_HAVE_GINT64
-      t = (gint64)value * jmp->scale * 1000 / jmp->rate;
-#else /* not G_HAVE_GINT64 */
-      t = value * jmp->scale * 1000 / jmp->rate;
-#endif /* not G_HAVE_GINT64 */
+      gchar *text;
+      gint t;
+      GtkWidget *label;
+      JumpConfig *jmpcfg;
+
+      label = g_object_get_data (G_OBJECT (widget), "user_data");
+      jmpcfg = g_object_get_data (G_OBJECT (dialog), "user_data");
+      t = (glonglong)value * jmpcfg->scale * 1000 / jmpcfg->rate;
       text = g_strdup_printf ("%02d:%02d:%02d",
                                 t / 60000 % 100, t / 1000 % 60, t / 10 % 100);
       gtk_label_set_text (GTK_LABEL (label), text);
       g_free (text);
-      gtk_widget_set_sensitive (button0, 0 <= value && value <= jmp->max);
+      gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_OK,
+                jmpcfg->frame != value && 0 <= value && value <= jmpcfg->max);
     }
   else
     {
-      gtk_widget_set_sensitive (button0, FALSE);
+      gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_OK,
+                                                                        FALSE);
     }
 }
 
@@ -92,67 +82,63 @@ jump_dialog_key_press (GtkWidget   *widget,
                        gpointer     user_data)
 {
   if (event->keyval == GDK_Escape)
-    gtk_widget_destroy (widget);
+    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
   return FALSE;
 }
 
 
 /*  ja:ジャンプダイアログ表示
-    jmp,ジャンプ構造体
-    RET.TRUE:OK,FALSE:Cancel                                                */
+    jmpcfg,ジャンプ構造体
+       RET.TRUE:OK,FALSE:Cancel                                             */
 gboolean
-jump_dialog (JumpDialog *jmp)
+jump_dialog (JumpConfig *jmpcfg)
 {
+  gboolean result;
   gchar *text;
-  GtkWidget *button1, *hbox, *vbox;
+  GtkWidget *dialog, *entry, *label, *vbox;
 
   /* ja:メインウインドウ */
-  dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_title (GTK_WINDOW (dialog), _("Jump"));
+  dialog = gtk_dialog_new_with_buttons
+                            (_("Jump"),
+                            GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
+                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            NULL);
   g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
                                     G_CALLBACK (jump_dialog_key_press), NULL);
-  g_signal_connect (G_OBJECT (dialog), "destroy", gtk_main_quit, NULL);
-  /* ja:ボタン */
-  button0 = gtk_button_new_with_label (_("OK"));
-  button1 = gtk_button_new_with_label (_("Cancel"));
-  g_signal_connect (G_OBJECT (button0), "clicked",
-                                        G_CALLBACK (jump_dialog_clicked), jmp);
-  g_signal_connect_swapped (G_OBJECT (button1), "clicked",
-                        G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
-  GTK_WIDGET_SET_FLAGS (button0, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (button1, GTK_CAN_DEFAULT);
+  g_object_set_data (G_OBJECT (dialog), "user_data", jmpcfg);
   /* ja:ラベル */
   label = gtk_label_new (NULL);
   /* ja:エントリー */
   entry = gtk_entry_new ();
+  g_object_set_data (G_OBJECT (entry), "user_data", label);
   g_signal_connect (G_OBJECT (entry), "changed",
-                                        G_CALLBACK (jump_dialog_changed), jmp);
-  text = misc_str_from_val (jmp->frame, 10, 0, FALSE);
+                                    G_CALLBACK (jump_dialog_changed), dialog);
+  text = misc_str_from_val (jmpcfg->frame, 10, 0, FALSE);
   gtk_entry_set_text (GTK_ENTRY (entry), text);
   g_free (text);
   g_signal_connect (G_OBJECT (entry), "activate",
-                                    G_CALLBACK (jump_dialog_activate), jmp);
+                                    G_CALLBACK (jump_dialog_activate), dialog);
   gtk_editable_select_region (GTK_EDITABLE (entry), 0, -1);
   /* ja:フレームとボックス */
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
   gtk_box_pack_start (GTK_BOX (vbox), entry, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-  hbox = gtk_hbox_new (FALSE, SPACING);
-  gtk_box_pack_end (GTK_BOX (hbox), button1, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (hbox), button0, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (dialog), vbox);
+  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), vbox);
 
   /* ja:表示 */
-  gtk_widget_set_sensitive (button0, FALSE);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_OK,
+                                                                        FALSE);
   gtk_widget_grab_focus (entry);
-  jump_clicked_ok = FALSE;
+  gtk_widget_show_all (vbox);
 
-  gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, TRUE, FALSE);
-  gtk_grab_add (dialog);
-  gtk_widget_show_all (dialog);
-  gtk_main ();
+  result = gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK;
+  if (result)
+    misc_str_to_val (&jmpcfg->frame,
+                            gtk_entry_get_text (GTK_ENTRY (entry)), 10, FALSE);
+  gtk_widget_destroy (dialog);
 
-  return jump_clicked_ok;
+  return result;
 }
