@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include "general.h"
 #include "sigfile.h"
 #include "misc/misc.h"
+#include "orz/orzmdi.h"
 
 
 /******************************************************************************
@@ -32,15 +33,19 @@
 gboolean
 signal_timeout (gpointer data)
 {
-  gint sx, page;
-  GdkRectangle rc;
-  VmaidWindow *vmaid;
+  gint page;
 
   caret =! caret;
-  if ((page = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook))) >= 0)
+#ifdef USE_THREAD
+  gdk_threads_enter ();
+#endif /* USE_THREAD */
+  if ((page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi))) >= 0)
     {
-      vmaid = g_object_get_data (G_OBJECT (gtk_notebook_get_nth_page
-                                (GTK_NOTEBOOK (notebook), page)), "user_data");
+      gint sx;
+      GdkRectangle rc;
+      VmaidWindow *vmaid;
+
+      vmaid = orz_mdi_get_data (ORZ_MDI (mdi), page);
       sx = MAX ((vmaid->drawing->allocation.width - 4) / vmaid->width - 2, 1);
       if (vmaid->top <= vmaid->cursor.frame
                                     && vmaid->cursor.frame <= vmaid->top + sx)
@@ -54,13 +59,16 @@ signal_timeout (gpointer data)
           gtk_widget_draw (vmaid->drawing, &rc);
         }
     }
+#ifdef USE_THREAD
+  gdk_threads_leave ();
+#endif /* USE_THREAD */
   return TRUE;
 }
 
 
 /******************************************************************************
 *                                                                             *
-* ja:シグナル/イベント関数群(フレーム)                                         *
+* ja:シグナル/イベント関数群(フレーム)                                        *
 *                                                                             *
 ******************************************************************************/
 gboolean
@@ -134,25 +142,15 @@ signal_destroy_draw (GtkWidget   *widget,
                      VmaidWindow *vmaid)
 {
   gint i;
-  GList *glist;
-  GtkWidget *menu_shell;
 
-  /* ja:ファイル名を調べる */
-  file_delete_edit (vmaid->file);
-  /* ja:ウインドウメニュー */
-  menu_shell = gtk_item_factory_get_widget (ifactory_menu, "<main>/Window");
-  gtk_container_remove (GTK_CONTAINER (menu_shell), vmaid->menu_item);
   /* ja:メニュー */
-  glist = gtk_container_children (GTK_CONTAINER (notebook));
-  if (g_list_length (glist) <= 1)
+  if (orz_mdi_get_n_pages (ORZ_MDI (mdi)) <= 1)
     {
       set_menu_bar (NULL);
       gtk_statusbar_pop (GTK_STATUSBAR (status),
             gtk_statusbar_get_context_id (GTK_STATUSBAR (status), "Status"));
     }
-  g_list_free (glist);
   /* ja:メモリを解放する */
-  g_free (vmaid->file);
   if (vmaid->timer_id != 0)
     {
       gtk_timeout_remove (vmaid->timer_id);
@@ -189,11 +187,7 @@ signal_expose_text (GtkWidget   *widget,
     gdk_draw_string (widget->window, system_font, gc,
                                                 x, system_font_ascent, text);
   g_free (text);
-#ifdef G_HAVE_GINT64
-  t = (gint64)pos * vmaid->scale * 1000 / vmaid->rate;
-#else /* not G_HAVE_GINT64 */
-  t = pos * vmaid->scale * 1000 / vmaid->rate;
-#endif /* not G_HAVE_GINT64 */
+  t = (glonglong)pos * vmaid->scale * 1000 / vmaid->rate;
   text = g_strdup_printf ("%02d:%02d:%02d",
                                 t / 60000 % 100, t / 1000 % 60, t / 10 % 100);
   if (gdk_string_width (system_font, text) <= vmaid->width)
@@ -225,40 +219,37 @@ signal_expose_bitmap (GtkWidget *widget,
 
 
 static void
-signal_expose_wave (GtkWidget    *widget,
-                    GdkGC        *gc,
-                    AviEdit      *avi_edit,
-                    WaveFormatEx *wfx,
-                    gint          current_time,
-                    gint          next_time,
-                    gint          x,
-                    gint          y,
-                    gint          width,
-                    gint          height)
+signal_expose_wave (GtkWidget  *widget,
+                    GdkGC      *gc,
+                    AviEdit    *avi_edit,
+                    AviPcm     *avi_pcm,
+                    const gint  current_time,
+                    const gint  next_time,
+                    const gint  x,
+                    const gint  y,
+                    const gint  width,
+                    const gint  height)
 {
-  guint8 *p = NULL;
-  gint i, j, x0, x1, y0, y1, start, end, samples, pos, length = 0, count;
-  GdkPoint pt[5];
+  gpointer out_buf = NULL;
+  gint start, end, count, out_samples = 0;
 
   start = 0;
   end = avi_length_time (avi_edit);
-  if (wfx)
+  if (avi_pcm)
     {
+      gint pos, samples;
+
       /* ja:範囲内のPCMを読み込む */
       pos = avi_time_to_sample (avi_edit, MAX (start, current_time));
       samples = avi_time_to_sample (avi_edit, MIN (end, next_time)) - pos;
       if (samples > avi_length (avi_edit) - pos)
         samples = avi_length (avi_edit) - pos;
-      length = avi_sample_size (avi_edit, pos, samples);
-      if (length > 0)
-        {
-          p = g_malloc (length);
-          if (!avi_read (avi_edit, pos, samples, p))
-            length = 0;
-        }
+      avi_get_pcm (avi_pcm, pos, samples, &out_buf, &out_samples);
     }
-  if (length <= 0)
+  if (out_samples <= 0)
     {
+      GdkPoint pt[5];
+
       /* ja:PCMが読み込めない */
       if (start <= current_time && next_time <= end)
         {
@@ -306,9 +297,9 @@ signal_expose_wave (GtkWidget    *widget,
         {
           count = 0;
         }
-      if (count>0)
+      if (count > 0)
         {
-          gdk_gc_set_foreground (gc,system_color + 2);
+          gdk_gc_set_foreground (gc, system_color + 2);
           gdk_gc_set_fill (gc, GDK_STIPPLED);
           gdk_draw_polygon (widget->window, gc, TRUE, pt, count);
           gdk_gc_set_foreground (gc, system_color);
@@ -318,6 +309,8 @@ signal_expose_wave (GtkWidget    *widget,
     }
   else
     {
+      gint i, x0, x1, y0, y1;
+
       /* ja:波形表示 */
       gdk_gc_set_foreground (gc, system_color);
       x0 = MAX (width * (start - current_time)
@@ -327,27 +320,40 @@ signal_expose_wave (GtkWidget    *widget,
       count = x1 - x0;
       for (i = 0; i < count; i++)
         {
+          gint j;
+
           /* ja:音量 */
-          j = i * length / count / wfx_get_block_align (wfx)
-                                                * wfx_get_block_align (wfx);
-          if (wfx_get_channels (wfx) == 1)
+          j = i * out_samples / count;
+          if (avi_get_bits_per_sample (avi_edit) == 8)
             {
-              if (wfx_get_bits_per_sample (wfx) == 8)
-                y0 = y1 = ABS (p[j] - 128) * height / 256;
-              else
-                y0 = y1 = ABS (*(gint16 *)(p + j)) * height / 65536;
-            }
-          else
-            {
-              if (wfx_get_bits_per_sample (wfx) == 8)
+              guint8 *p;
+
+              p = out_buf;
+              if (avi_get_channels (avi_edit) == 1)
                 {
-                  y0 = ABS (p[j] - 128) * height / 256;
-                  y1 = ABS (p[j + 1] - 128) * height / 256;
+                  y0 = y1 = ABS (p[j] - 128) * height / 256;
                 }
               else
                 {
-                  y0 = ABS (*(gint16 *)(p + j)) * height / 65536;
-                  y1 = ABS (*(gint16 *)(p + j + 2)) * height / 65536;
+                  j *= 2;
+                  y0 = ABS (p[j] - 128) * height / 256;
+                  y1 = ABS (p[j + 1] - 128) * height / 256;
+                }
+            }
+          else
+            {
+              gint16 *p;
+
+              p = out_buf;
+              if (avi_get_channels (avi_edit) == 1)
+                {
+                  y0 = y1 = ABS (GINT16_FROM_LE (p[j])) * height / 65536;
+                }
+              else
+                {
+                  j *= 2;
+                  y0 = ABS (GINT16_FROM_LE (p[j])) * height / 65536;
+                  y1 = ABS (GINT16_FROM_LE (p[j + 1])) * height / 65536;
                 }
             }
           gdk_gc_set_foreground (gc, system_color + 2);
@@ -359,7 +365,7 @@ signal_expose_wave (GtkWidget    *widget,
       gdk_draw_line (widget->window, gc,
                                     x0, y + height / 2, x1, y + height / 2);
     }
-  g_free (p);
+  g_free (out_buf);
 }
 
 
@@ -368,9 +374,7 @@ signal_expose (GtkWidget      *widget,
                GdkEventExpose *event,
                VmaidWindow    *vmaid)
 {
-  gint i, sx, max, frame, size;
-  AviFrame *avi_frame;
-  WaveFormatEx *wfx;
+  gint i, sx, max, frame;
   GdkGC *gc;
   GdkRectangle rc0, rc1;
 
@@ -407,6 +411,8 @@ signal_expose (GtkWidget      *widget,
   rc0.height = vmaid->height;
   if (vmaid->avi_edit[0])
     {
+      AviFrame *avi_frame;
+
       avi_frame = avi_get_frame_open (vmaid->avi_edit[0]);
       max = MIN (get_max_frame (vmaid, 0), vmaid->top + sx - 1);
       rc0.x = 0;
@@ -467,6 +473,8 @@ signal_expose (GtkWidget      *widget,
     }
   if (vmaid->avi_edit[1])
     {
+      AviPcm *avi_pcm;
+
       /* ja:背景 */
       rc0.x = event->area.x;
       rc0.width = event->area.width;
@@ -476,60 +484,33 @@ signal_expose (GtkWidget      *widget,
           gdk_draw_rectangle (widget->window, gc, TRUE,
                                         rc1.x, rc1.y, rc1.width, rc1.height);
         }
-      size = avi_format_size (vmaid->avi_edit[1]);
-      wfx = g_malloc (size);
-      avi_read_format (vmaid->avi_edit[1], wfx);
-      if (wfx_get_format_tag (wfx) != WAVE_FORMAT_PCM
-            || (wfx_get_channels (wfx) != 1 && wfx_get_channels (wfx) != 2)
-            || (wfx_get_bits_per_sample (wfx) != 8
-                                        && wfx_get_bits_per_sample (wfx) != 16)
-            || wfx_get_block_align (wfx) * 8
-                    != wfx_get_channels (wfx) * wfx_get_bits_per_sample (wfx))
-        {
-          g_free (wfx);
-          wfx = NULL;
-        }
+      avi_pcm = avi_get_pcm_open (vmaid->avi_edit[1]);
       max = MIN (get_max_frame (vmaid, 1), vmaid->top + sx - 1);
       rc0.x = 0;
       rc0.width = vmaid->width;
       if (frame >= 0 && frame < vmaid->top
                         && gdk_rectangle_intersect (&event->area, &rc0, &rc1))
         /* ja:選択開始位置が前のとき */
-        signal_expose_wave (widget, gc, vmaid->avi_edit[1], wfx,
-#ifdef G_HAVE_GINT64
-                (gint)(gint64)frame * vmaid->scale * 1000 / vmaid->rate,
-                (gint)(gint64)(frame + 1) * vmaid->scale * 1000 / vmaid->rate,
-#else /* not G_HAVE_GINT64 */
-                            frame * vmaid->scale * 1000 / vmaid->rate,
-                            (frame + 1) * vmaid->scale * 1000 / vmaid->rate,
-#endif /* not G_HAVE_GINT64 */
+        signal_expose_wave (widget, gc, vmaid->avi_edit[1], avi_pcm,
+            (gint)((glonglong)frame * vmaid->scale * 1000 / vmaid->rate),
+            (gint)((glonglong)(frame + 1) * vmaid->scale * 1000 / vmaid->rate),
                                         rc0.x, rc0.y, rc0.width, rc0.height);
-      for (i = vmaid->top,rc0.x = vmaid->width + 2; i <= max;
+      for (i = vmaid->top, rc0.x = vmaid->width + 2; i <= max;
                                                 i++, rc0. x += vmaid->width)
         if (gdk_rectangle_intersect (&event->area, &rc0, &rc1))
-          signal_expose_wave (widget, gc, vmaid->avi_edit[1], wfx,
-#ifdef G_HAVE_GINT64
-                    (gint)(gint64)i * vmaid->scale * 1000 / vmaid->rate,
-                    (gint)(gint64)(i + 1)*vmaid->scale * 1000 / vmaid->rate,
-#else /* not G_HAVE_GINT64 */
-                                i * vmaid->scale * 1000 / vmaid->rate,
-                                (i + 1) * vmaid->scale * 1000 / vmaid->rate,
-#endif /* not G_HAVE_GINT64 */
+          signal_expose_wave (widget, gc, vmaid->avi_edit[1], avi_pcm,
+                (gint)((glonglong)i * vmaid->scale * 1000 / vmaid->rate),
+                (gint)((glonglong)(i + 1)*vmaid->scale * 1000 / vmaid->rate),
                                         rc0.x, rc0.y, rc0.width, rc0.height);
       rc0.x = vmaid->width * (sx + 1) + 4;
       if (vmaid->top + sx <= frame
                         && gdk_rectangle_intersect (&event->area, &rc0, &rc1))
         /* ja:選択開始位置が後のとき */
-        signal_expose_wave (widget, gc, vmaid->avi_edit[1], wfx,
-#ifdef G_HAVE_GINT64
-                (gint)(gint64)frame * vmaid->scale * 1000 / vmaid->rate,
-                (gint)(gint64)(frame + 1) * vmaid->scale * 1000 / vmaid->rate,
-#else /* not G_HAVE_GINT64 */
-                            frame * vmaid->scale * 1000 / vmaid->rate,
-                            (frame + 1) * vmaid->scale * 1000 / vmaid->rate,
-#endif /* not G_HAVE_GINT64 */
+        signal_expose_wave (widget, gc, vmaid->avi_edit[1], avi_pcm,
+            (gint)((glonglong)frame * vmaid->scale * 1000 / vmaid->rate),
+            (gint)((glonglong)(frame + 1) * vmaid->scale * 1000 / vmaid->rate),
                                         rc0.x, rc0.y, rc0.width, rc0.height);
-      g_free (wfx);
+      avi_get_pcm_close (avi_pcm);
     }
   /* ja:選択範囲 */
   if (vmaid->select.stream >= 0)
@@ -648,17 +629,22 @@ signal_button_press_draw (GtkWidget      *widget,
             case 2:/* ja:中クリック */
               break;
             case 3:/* ja:右クリック */
-              gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                (ifactory_popup, "<main>/Undo"), vmaid->undo != NULL);
-              gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                (ifactory_popup, "<main>/Cut"), vmaid->select.stream >= 0);
-              gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                (ifactory_popup, "<main>/Copy"), vmaid->select.stream >= 0);
-              gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                (ifactory_popup, "<main>/Delete"), vmaid->select.stream >= 0);
-              gtk_menu_popup (GTK_MENU
-                    (gtk_item_factory_get_widget (ifactory_popup, "<main>")),
+              {
+                GtkWidget *menu_shell;
+
+                gtk_widget_set_sensitive (misc_find_menu (popup_entries,
+                                        "/undo"), vmaid->undo != NULL);
+                gtk_widget_set_sensitive (misc_find_menu (popup_entries,
+                                        "/cut"), vmaid->select.stream >= 0);
+                gtk_widget_set_sensitive (misc_find_menu (popup_entries,
+                                        "/copy"), vmaid->select.stream >= 0);
+                gtk_widget_set_sensitive (misc_find_menu (popup_entries,
+                                        "/delete"), vmaid->select.stream >= 0);
+                menu_shell = misc_find_menu (popup_entries, "/");
+                gtk_widget_show_all (menu_shell);
+                gtk_menu_popup (GTK_MENU (menu_shell),
                         NULL, NULL, NULL, NULL, event->button, event->time);
+              }
           }
         break;
       default:
@@ -669,7 +655,7 @@ signal_button_press_draw (GtkWidget      *widget,
 
 
 /*  ja:マウスの移動に関する処理
-      ptw,テキスト情報
+    vmaid,テキスト情報
         x,X座標
         y,Y座標
     state,ステータス
@@ -811,7 +797,7 @@ signal_scroll (GtkWidget      *widget,
                             || event->direction == GDK_SCROLL_LEFT ? -4 : 4;
   if (vmaid->top < 0)
     vmaid->top = 0;
-  else if (vmaid->top>max - sx)
+  else if (vmaid->top > max - sx)
     vmaid->top = MAX (max - sx, 0);
   if (vmaid->top != top)
     misc_set_scroll_bar (vmaid->hscroll,
@@ -840,7 +826,7 @@ signal_key_press (GtkWidget   *widget,
       case GDK_K:
       case GDK_j:
       case GDK_k:
-        if (!(event->state&GDK_MOD1_MASK))
+        if (!(event->state & GDK_MOD1_MASK))
           break;
       case GDK_Up:
       case GDK_Down:
@@ -859,8 +845,8 @@ signal_key_press (GtkWidget   *widget,
           vmaid->cursor.stream = vmaid->cursor.stream == 0 ? 1 : 0;
           /* ja:キャレットが表示されるように調整 */
           if (vmaid->top > vmaid->cursor.frame)
-            vmaid->top = vmaid->cursor.frame;
-          else if (vmaid->top < vmaid->cursor.frame - sx)
+            vmaid->top = MIN (vmaid->cursor.frame, max - sx);
+          if (vmaid->top < vmaid->cursor.frame - sx)
             vmaid->top = MAX (vmaid->cursor.frame - sx, 0);
           if (vmaid->select.stream >= 0 && !(event->state & GDK_SHIFT_MASK))
             {
@@ -973,8 +959,8 @@ signal_key_press (GtkWidget   *widget,
             vmaid->cursor.frame = max;
           /* ja:キャレットが表示されるように調整 */
           if (vmaid->top > vmaid->cursor.frame)
-            vmaid->top = vmaid->cursor.frame;
-          else if (vmaid->top < vmaid->cursor.frame - sx)
+            vmaid->top = MIN (vmaid->cursor.frame, max - sx);
+          if (vmaid->top < vmaid->cursor.frame - sx)
             vmaid->top = MAX (vmaid->cursor.frame - sx, 0);
           if (vmaid->cursor.frame == cursor.frame && vmaid->top == top)
             break;/* ja:変化なし */
@@ -1016,8 +1002,9 @@ signal_key_press (GtkWidget   *widget,
           sx = MAX ((widget->allocation.width - 4) / vmaid->width - 2, 1);
           /* ja:キャレットが表示されるように調整 */
           if (vmaid->top > vmaid->cursor.frame)
-            vmaid->top = vmaid->cursor.frame;
-          else if (vmaid->top < vmaid->cursor.frame - sx)
+            vmaid->top = MIN (vmaid->cursor.frame,
+                                        get_max_frame (vmaid, -1) + 1 - sx);
+          if (vmaid->top < vmaid->cursor.frame - sx)
             vmaid->top = MAX (vmaid->cursor.frame - sx, 0);
           vmaid->select.stream = -1;/* ja:選択解除 */
           /* ja:メニュー */
@@ -1059,7 +1046,7 @@ signal_key_press (GtkWidget   *widget,
                 }
               vmaid->select.stream = vmaid->cursor.stream;
             }
-          command_delete (NULL, 0, widget);
+          command_delete (widget, NULL);
         }
         break;
       case GDK_F10:
@@ -1072,24 +1059,24 @@ signal_key_press (GtkWidget   *widget,
           sx = MAX ((widget->allocation.width - 4) / vmaid->width - 2, 1);
           /* ja:キャレットが表示されるように調整 */
           if (vmaid->top > vmaid->cursor.frame)
-            vmaid->top = vmaid->cursor.frame;
-          else if (vmaid->top < vmaid->cursor.frame - sx)
+            vmaid->top = MIN (vmaid->cursor.frame,
+                                        get_max_frame (vmaid, -1) + 1 - sx);
+          if (vmaid->top < vmaid->cursor.frame - sx)
             vmaid->top = MAX (vmaid->cursor.frame - sx, 0);
           if (vmaid->top != top)
             misc_set_scroll_bar (vmaid->hscroll,
                     GTK_SIGNAL_FUNC (signal_value_changed_hscroll),
                     vmaid, 0, get_max_frame (vmaid, -1) + 1, sx, vmaid->top);
           clear_sel (vmaid, &vmaid->cursor, &vmaid->select, top);
-          gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                (ifactory_popup, "<main>/Undo"), vmaid->undo != NULL);
-          gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                (ifactory_popup, "<main>/Cut"), vmaid->select.stream >= 0);
-          gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                (ifactory_popup, "<main>/Copy"), vmaid->select.stream >= 0);
-          gtk_widget_set_sensitive (gtk_item_factory_get_widget
-                (ifactory_popup, "<main>/Delete"), vmaid->select.stream >= 0);
-          gtk_menu_popup (GTK_MENU
-                    (gtk_item_factory_get_widget (ifactory_popup, "<main>")),
+          gtk_widget_set_sensitive (misc_find_menu (popup_entries, "/undo"),
+                                                    vmaid->undo != NULL);
+          gtk_widget_set_sensitive (misc_find_menu (popup_entries, "/cut"),
+                                                    vmaid->select.stream >= 0);
+          gtk_widget_set_sensitive (misc_find_menu (popup_entries, "/copy"),
+                                                    vmaid->select.stream >= 0);
+          gtk_widget_set_sensitive (misc_find_menu (popup_entries, "/delete"),
+                                                    vmaid->select.stream >= 0);
+          gtk_menu_popup (GTK_MENU (misc_find_menu (popup_entries, "/")),
                                     NULL, NULL, NULL, NULL, 3, event->time);
         }
         result=TRUE;
@@ -1100,12 +1087,9 @@ signal_key_press (GtkWidget   *widget,
         {
           gint page;
           guint length;
-          GList *glist;
 
-          glist = gtk_container_children (GTK_CONTAINER (notebook));
-          length = g_list_length (glist);
-          g_list_free (glist);
-          page = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
+          length = orz_mdi_get_n_pages (ORZ_MDI (mdi));
+          page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
           if (event->state & GDK_SHIFT_MASK)
             {
               if (--page < 0)
@@ -1116,10 +1100,9 @@ signal_key_press (GtkWidget   *widget,
               if (++page >= length)
                 page = 0;
             }
-          gtk_notebook_set_page (GTK_NOTEBOOK (notebook), page);
-          gtk_widget_grab_focus (((VmaidWindow *) g_object_get_data (G_OBJECT
-                    (gtk_notebook_get_nth_page (GTK_NOTEBOOK(notebook),page)),
-                                                    "user_data"))->drawing);
+          gtk_notebook_set_page (GTK_NOTEBOOK (mdi), page);
+          gtk_widget_grab_focus (((VmaidWindow *)
+                            orz_mdi_get_data (ORZ_MDI (mdi), page))->drawing);
         }
     }
   loop:
