@@ -24,8 +24,8 @@
 #include "thread.h"
 #include "misc/argument.h"
 #include "misc/misc.h"
-#include "misc/misc_history.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzhistory.h"
+#include "orz/orzmdi.h"
 
 
 /******************************************************************************
@@ -60,11 +60,11 @@ signal_style_set (GtkWidget *widget,
       if (system_font_height < height)
         system_font_height = height;
     }
-  for (i = misc_mdi_get_n_pages (MISC_MDI (mdi)) - 1; i >= 0; i--)
+  for (i = orz_mdi_get_n_pages (ORZ_MDI (mdi)) - 1; i >= 0; i--)
     {
       VmaidWindow *vmaid;
 
-      vmaid = misc_mdi_get_data (MISC_MDI (mdi), i);
+      vmaid = orz_mdi_get_data (ORZ_MDI (mdi), i);
       gtk_widget_set_usize (vmaid->drawing, vmaid->width * 3 + 4,
                         system_font_height * 2 + ((vmaid->avi_edit[0] ? 1 : 0)
                             + (vmaid->avi_edit[1] ? 1 : 0)) * vmaid->height);
@@ -148,13 +148,35 @@ void
 signal_changed (GtkTreeSelection *select,
                 gpointer          user_data)
 {
-  gint count;
+  gint count = 0;
 
   gtk_tree_selection_selected_foreach (select, signal_tree_selection_foreach,
                                                                     &count);
-  gtk_widget_set_sensitive (gtk_menu_get_attach_widget (GTK_MENU
-                (gtk_item_factory_get_widget (ifactory_menu, "<main>/Task"))),
+  gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/task"), count > 0);
+}
+
+
+gboolean
+signal_button_press_tview (GtkWidget        *widget,
+                           GdkEventButton   *event,
+                           GtkTreeSelection *select)
+{
+  if (event->type == GDK_BUTTON_PRESS && event->button == 3)
+    {
+      gint count = 0;
+      GtkWidget *menu_shell;
+
+      gtk_tree_selection_selected_foreach (select,
+                                        signal_tree_selection_foreach, &count);
+      gtk_widget_set_sensitive (misc_find_menu (tview_entries, "/cancel"),
                                                                     count > 0);
+      menu_shell = misc_find_menu (tview_entries, "/");
+      gtk_widget_show_all (menu_shell);
+      gtk_menu_popup (GTK_MENU (menu_shell),
+                        NULL, NULL, NULL, NULL, event->button, event->time);
+      return TRUE;
+    }
+  return FALSE;
 }
 
 
@@ -176,7 +198,7 @@ signal_drag_data_received (GtkWidget        *widget,
   gint i;
   FileOpen *file_open;
 
-  files = g_strsplit (selection_data->data, "\r\n", G_MAXINT);
+  files = g_strsplit (selection_data->data, "\r\n", 0);
   for (i = 0; files[i]; i++)
     {
       file = g_filename_from_uri (files[i], NULL, NULL);
@@ -232,7 +254,6 @@ signal_selection_received (GtkWidget        *widget,
                            guint             time,
                            gpointer          user_data)
 {
-
   if (data->selection == GDK_SELECTION_CLIPBOARD && data->length >= 0)
     {
       /* ja:クリップボード */
@@ -265,50 +286,55 @@ signal_selection_received (GtkWidget        *widget,
           if (!avi_edit)
             return;
           page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-          vmaid = misc_mdi_get_data (MISC_MDI (mdi), page_num);
+          vmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
           if (vmaid->select.stream < 0)
             {
               /* ja:選択範囲がないときUNDOの準備 */
-              d = g_malloc (sizeof (VmaidHistory));
+              d = g_malloc0 (sizeof (VmaidHistory));
               for (i = 0; i < 2; i++)
-                {
-                  d->avi_edit[i] = NULL;
-                  if (vmaid->avi_edit[i]
+                if (vmaid->avi_edit[i]
                         && !(d->avi_edit[i] = avi_clone (vmaid->avi_edit[i])))
-                    result = FALSE;
-                }
+                  result = FALSE;
               if (!result)
                 {
-                  misc_message_box ("Video maid", _("AVI Clone Error"), 0,
-                                                                _("OK"), NULL);
+                  GtkWidget *dialog;
+
+                  dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
+                            _("AVI Clone Error"));
+                  gtk_dialog_run (GTK_DIALOG (dialog));
+                  gtk_widget_destroy (dialog);
                   for (i = 0; i < 2; i++)
                     if (d->avi_edit[i])
-                      avi_release(d->avi_edit[i]);
-                  g_free(d);
+                      avi_release (d->avi_edit[i]);
+                  g_free (d);
                   for (i = 0; avi_edit[i]; i++)
                     avi_release (avi_edit[i]);
                   g_free (avi_edit);
                   return;
                 }
-              d->cursor=vmaid->cursor;
-              d->select=vmaid->select;
+              d->cursor = vmaid->cursor;
+              d->select = vmaid->select;
+              d->next = vmaid->undo;
+              vmaid->undo = d;
             }
           else
             {
               /* ja:選択範囲があればそれを削除する */
               d = vmaid->redo;
               vmaid->redo = NULL;
-              command_delete (NULL, 0, widget);
+              command_delete (widget, NULL);
               vmaid->redo = d;
             }
           paste[0] = paste[1] = FALSE;
           for (i = 0; avi_edit[i]; i++)
-            switch (avi_type(avi_edit[i]))
+            switch (avi_type (avi_edit[i]))
               {
-                case AVI_STREAM_VIDEO:
+                case AVI_TYPE_VIDEO:
                   if (paste[0])
                     {
-                      avi_release(avi_edit[i]);
+                      avi_release (avi_edit[i]);
                     }
                   else
                     {
@@ -321,16 +347,16 @@ signal_selection_received (GtkWidget        *widget,
                                             avi_length (vmaid->avi_edit[0])),
                                                                 avi_edit[i]))
                         {
-                          avi_release(avi_edit[i]);
+                          avi_release (avi_edit[i]);
                           result = FALSE;
                         }
                       paste[0] = TRUE;
                     }
                   break;
-                case AVI_STREAM_AUDIO:
+                case AVI_TYPE_AUDIO:
                   if (paste[1])
                     {
-                      avi_release(avi_edit[i]);
+                      avi_release (avi_edit[i]);
                     }
                   else
                     {
@@ -339,17 +365,10 @@ signal_selection_received (GtkWidget        *widget,
                           vmaid->avi_edit[1] = avi_edit[i];
                         }
                       else if (!avi_paste (vmaid->avi_edit[1],
-#ifdef G_HAVE_GINT64
                             MIN (avi_time_to_sample (vmaid->avi_edit[1],
-                                            (gint64)vmaid->cursor.frame * 1000
-                                                * vmaid->scale / vmaid->rate),
-                                        avi_length (vmaid->avi_edit[0])),
-#else /* not G_HAVE_GINT64 */
-                            MIN (avi_time_to_sample (vmaid->avi_edit[1],
-                                                    vmaid->cursor.frame * 1000
-                                                * vmaid->scale / vmaid->rate),
-                                        avi_length (vmaid->avi_edit[0])),
-#endif /* not G_HAVE_GINT64 */
+                                (gint)((glonglong)vmaid->cursor.frame * 1000
+                                                * vmaid->scale / vmaid->rate)),
+                                        avi_length (vmaid->avi_edit[1])),
                                                                 avi_edit[i]))
                         {
                           avi_release (avi_edit[i]);
@@ -365,11 +384,17 @@ signal_selection_received (GtkWidget        *widget,
           g_free (avi_edit);
           if (!result || (!paste[0] && !paste[1]))
             {
-              misc_message_box ("Video maid", _("AVI Paste Error"), 0,
-                                                                _("OK"), NULL);
+              GtkWidget *dialog;
+
+              dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
+                            _("AVI Paste Error"));
+              gtk_dialog_run (GTK_DIALOG (dialog));
+              gtk_widget_destroy (dialog);
               for (i = 0; i < 2; i++)
                 if (vmaid->avi_edit[i])
-                  avi_release(vmaid->avi_edit[i]);
+                  avi_release (vmaid->avi_edit[i]);
               d = vmaid->undo;
               vmaid->undo = vmaid->undo->next;
               for (i = 0; i < 2; i++)
@@ -391,9 +416,10 @@ signal_selection_received (GtkWidget        *widget,
             vmaid->cursor.stream = 1;
           if (vmaid->cursor.frame > max)
             vmaid->cursor.frame = max;
+          /* ja:キャレットが表示されるように調整 */
           if (vmaid->top > vmaid->cursor.frame)
-            vmaid->top=vmaid->cursor.frame;
-          else if (vmaid->top < vmaid->cursor.frame - sx)
+            vmaid->top = MIN (vmaid->cursor.frame, max - sx);
+          if (vmaid->top < vmaid->cursor.frame - sx)
             vmaid->top = MAX (vmaid->cursor.frame - sx, 0);
           /* ja:メニュー,ステートメント,子ウインドウ */
           set_menu_bar (vmaid);
@@ -406,7 +432,7 @@ signal_selection_received (GtkWidget        *widget,
           misc_set_scroll_bar (vmaid->hscroll,
                                 GTK_SIGNAL_FUNC (signal_value_changed_hscroll),
                                                 vmaid, 0, max, sx, vmaid->top);
-          misc_mdi_set_edited (MISC_MDI (mdi), page_num, TRUE);
+          orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
         }
     }
 }
@@ -431,15 +457,15 @@ signal_selection_recv (GObject   *object,
 
   /* ja:プロセス間通信 */
   /* ja:ファイルの履歴 */
-  arg_h.val = misc_history_get_num (MISC_HISTORY (history));
-  arg_h.def = MISC_HISTORY_NUM_DEF;
+  arg_h.val = orz_history_get_num (ORZ_HISTORY (history));
+  arg_h.def = ORZ_HISTORY_NUM_DEF;
   /* ja:新規ファイル */
   arg_n.flag = newfile;
   arg_n.def = FALSE;
   /* ja:ウインドウサイズ */
   array[0] = def_width;
   array[1] = def_height;
-  def[0] = gdk_screen_width ()  * 2 / 3;
+  def[0] = gdk_screen_width () * 2 / 3;
   def[1] = gdk_screen_height () * 2 / 3;
   arg_s.leng = 2;
   arg_s.array = array;
@@ -449,7 +475,7 @@ signal_selection_recv (GObject   *object,
   arg_x.def = FALSE;
   /* ja:コマンドラインの解析 */
   arg_files = arg_analyse (argv, arg_opts);
-  misc_history_set_num (MISC_HISTORY (history), arg_h.val);
+  orz_history_set_num (ORZ_HISTORY (history), arg_h.val);
   newfile = arg_n.flag;
   def_width = array[0];
   def_height = array[1];
@@ -487,7 +513,7 @@ signal_delete (GtkWidget *widget,
   while ((page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi))) >= 0)
     {
       if (!prompt_close ((VmaidWindow *)
-                                    misc_mdi_get_data (MISC_MDI (mdi), page)))
+                                    orz_mdi_get_data (ORZ_MDI (mdi), page)))
         return TRUE;
       gtk_notebook_remove_page (GTK_NOTEBOOK (mdi), page);
     }
