@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ extern "C" {
 #endif /* not USE_THREAD */
 
 
-typedef struct ThreadList_Tag
+typedef struct _ThreadList
 {
   gboolean userbreak;   /* ja:TRUE:継続,FALSE:中断要求 */
   gint mode;            /* ja:0:終了,1:開く,2:保存,3:フレーム数,4:反転 */
@@ -119,4 +119,4 @@ close_program (void);
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __THREAD_H__ */
