@@ -26,7 +26,7 @@
 *                                                                             *
 ******************************************************************************/
 /* XPM */
-static const gchar *tb_new_xpm[] = {
+const static gchar *tb_new_xpm[] = {
 "16 16 4 1",
 "   c None",
 ".  c #000000",
@@ -51,7 +51,7 @@ static const gchar *tb_new_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_open_xpm[] = {
+const static gchar *tb_open_xpm[] = {
 "16 16 5 1",
 "   c None",
 ".  c #000000",
@@ -77,7 +77,7 @@ static const gchar *tb_open_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_save_xpm[] = {
+const static gchar *tb_save_xpm[] = {
 "16 16 5 1",
 "  c None",
 ". c #000000",
@@ -102,7 +102,7 @@ static const gchar *tb_save_xpm[] = {
 "                "};
 
 
-static const gchar *tb_prop_xpm[] = {
+const static gchar *tb_prop_xpm[] = {
 "16 16 4 1",
 "  c None",
 ". c #000000",
@@ -127,7 +127,7 @@ static const gchar *tb_prop_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_preview_xpm[] = {
+const static gchar *tb_preview_xpm[] = {
 "16 16 5 1",
 "   c None",
 ".  c #000000",
@@ -153,7 +153,7 @@ static const gchar *tb_preview_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_cut_xpm[] = {
+const static gchar *tb_cut_xpm[] = {
 "16 16 5 1",
 "   c None",
 ".  c #000000",
@@ -179,7 +179,7 @@ static const gchar *tb_cut_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_copy_xpm[] = {
+const static gchar *tb_copy_xpm[] = {
 "16 16 4 1",
 "   c None",
 ".  c #000000",
@@ -204,7 +204,7 @@ static const gchar *tb_copy_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_paste_xpm[] = {
+const static gchar *tb_paste_xpm[] = {
 "16 16 5 1",
 "   c None",
 ".  c #000000",
@@ -230,7 +230,7 @@ static const gchar *tb_paste_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_delete_xpm[] = {
+const static gchar *tb_delete_xpm[] = {
 "16 16 2 1",
 "   c None",
 ",  c #0000FF",
@@ -253,7 +253,7 @@ static const gchar *tb_delete_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_undo_xpm[] = {
+const static gchar *tb_undo_xpm[] = {
 "16 16 2 1",
 "   c None",
 "-  c #FF0000",
@@ -276,7 +276,7 @@ static const gchar *tb_undo_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_redo_xpm[] = {
+const static gchar *tb_redo_xpm[] = {
 "16 16 2 1",
 "   c None",
 ",  c #0000FF",
