@@ -17,7 +17,8 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include "version.h"
-#include "misc/license.h"
+#include "avicore/icm.h"
+#include "misc/gnugpl.h"
 #include <gdk/gdkkeysyms.h>
 
 
@@ -63,9 +64,39 @@ version_dialog_row_deleted (GtkTreeModel *model,
 /* ja:Aboutボタンが押された */
 static void
 version_dialog_clicked (GtkWidget *widget,
-                        GtkWidget *ctree)
+                        GtkWidget *tview)
 {
-  icm_dialog_about (g_object_get_data (G_OBJECT (ctree), "user_data"));
+  icm_dialog_about (g_object_get_data (G_OBJECT (tview), "user_data"));
+}
+
+
+/* ja:ダブルクリックされたとき */
+static gboolean
+version_dialog_button_press (GtkWidget      *widget,
+                             GdkEventButton *event,
+                             gpointer        user_data)
+{
+  gboolean result = FALSE;
+
+  if (event->type == GDK_2BUTTON_PRESS && event->button == 1)
+    {
+      GtkTreePath *path;
+
+      if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (widget),
+                    (gint)event->x, (gint)event->y, &path, NULL, NULL, NULL))
+        {
+          GtkTreeIter iter;
+
+          if (gtk_tree_model_get_iter (gtk_tree_view_get_model
+                                        (GTK_TREE_VIEW (widget)), &iter, path))
+            {
+              version_dialog_clicked (widget, widget);
+              result = TRUE;
+            }
+          gtk_tree_path_free (path);
+        }
+    }
+  return result;
 }
 
 
@@ -76,7 +107,7 @@ version_dialog_key_press (GtkWidget   *widget,
                           gpointer     user_data)
 {
   if (event->keyval == GDK_Escape)
-    gtk_widget_destroy(widget);
+    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
   return FALSE;
 }
 
@@ -84,20 +115,18 @@ version_dialog_key_press (GtkWidget   *widget,
 void
 version_dialog (void)
 {
-  gchar *str[3];
-  gint i,length;
+  gint i;
   GList *glist;
   GdkPixbuf *pixbuf;
   GtkTextBuffer *buffer;
   GtkTextIter where;
-  GtkTreeIter iter,iter_parent;
+  GtkTreeIter iter_parent;
   GtkTreeSelection *select;
   GtkTreeStore *store;
   GtkTreeViewColumn *column;
   GtkWidget *button, *notebook, *text, *tview;
-  GtkWidget *dialog, *scroll, *hbox0, *hbox1, *vbox;
-  IcmObject *icm_object;
-  IcmInfo icm_info;
+  GtkWidget *dialog, *scroll, *hbox0, *hbox1 ,*vbox;
+const static gchar *str[3] = {N_("Name"), N_("Code"), N_("Attribute")};
 const static gchar *authors =
 "Main Program :\n"
 "    Kazuki IWAMOTO\n"
@@ -118,7 +147,7 @@ const static gchar *authors =
 "    ryoma\n"
 "    And all Video maid users";
 /* XPM */
-static const gchar *vmaid_xpm[] = {
+const static gchar *vmaid_xpm[] = {
 "32 32 16 1",
 "   c None",
 ".  c #000000",
@@ -170,13 +199,17 @@ static const gchar *vmaid_xpm[] = {
 "                                "};
 
   /* ja:メインウインドウ */
-  dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_title (GTK_WINDOW (dialog), _("About Video maid"));
+  dialog = gtk_dialog_new_with_buttons
+                            (_("About Video maid"),
+                            GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
+                            NULL);
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
   gtk_window_set_default_size (GTK_WINDOW (dialog),
                     gdk_screen_width () * 2 / 3, gdk_screen_height () * 2 / 3);
   g_signal_connect (G_OBJECT (dialog), "key-press-event",
                                 G_CALLBACK (version_dialog_key_press), NULL);
-  g_signal_connect (G_OBJECT (dialog), "destroy", gtk_main_quit, NULL);
   /* ja:ノートブック */
   notebook = gtk_notebook_new ();
   gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook), TRUE);
@@ -186,7 +219,7 @@ static const gchar *vmaid_xpm[] = {
   /* ja:テキスト */
   text = gtk_text_view_new ();
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text));
-  gtk_text_buffer_set_text (buffer, gnu_gpl, -1);
+  gtk_text_buffer_set_text (buffer, gnugpl, -1);
   gtk_text_buffer_get_start_iter (buffer, &where);
   gtk_text_buffer_place_cursor (buffer, &where);
   gtk_text_view_set_editable (GTK_TEXT_VIEW (text), FALSE);
@@ -231,48 +264,53 @@ static const gchar *vmaid_xpm[] = {
   glist = icm_get_handler_list ();
   if (glist)
     {
+      gint length;
+
       length = g_list_length (glist);
       for (i = 0; i < length; i++)
         {
+          IcmObject *icm_object;
+
           icm_object = icm_open ((guint32)g_list_nth_data (glist, i),
                                                             ICM_MODE_QUERY);
           if (icm_object)
             {
-              if (icm_get_info (icm_object, &icm_info))
+              gchar *handler;
+              const gchar *name, *attribute;
+
+              name = icm_get_name (icm_object);
+              handler = icm_handler_to_string (icm_get_handler (icm_object));
+              switch (icm_get_attribute (icm_object))
                 {
-                  str[1] = icm_handler_to_string (icm_info.handler);
-                  switch (icm_info.attribute)
-                    {
-                      case ICM_ATTR_NATIVE:
-                        str[2] = _("Video maid Native");
-                        break;
-                      case ICM_ATTR_WIN32:
+                  case ICM_ATTR_NATIVE:
+                    attribute = _("Video maid Native");
+                    break;
+                  case ICM_ATTR_WIN32:
 #ifdef G_OS_WIN32
-                        str[2] = _("Win32 Native");
+                    attribute = _("Win32 Native");
 #else /* not G_OS_WIN32 */
-                        str[2] = _("Win32 Emulation");
+                    attribute = _("Win32 Emulation");
 #endif /* not G_OS_WIN32 */
-                        break;
-                      default:
-                        str[2] = _("Unknown");
-                    }
+                    break;
+                  default:
+                    attribute = _("Unknown");
+                }
+              if (name && handler)
+                {
+                  GtkTreeIter iter;
+
                   gtk_tree_store_append (store, &iter, &iter_parent);
-                  gtk_tree_store_set (store, &iter, 0, icm_info.name,
-                                                    1, str[1],
-                                                    2, str[2],
+                  gtk_tree_store_set (store, &iter, 0, name,
+                                                    1, handler,
+                                                    2, attribute,
                                                     3, NULL,
                                                     -1);
-                  g_free (str[1]);
-                  g_free (icm_info.name);
                   if (icm_is_dialog_about (icm_object))
                     gtk_tree_store_set (store, &iter, 3, icm_object, -1);
                   else
                     icm_close (icm_object);
                 }
-              else
-                {
-                  icm_close (icm_object);
-                }
+              g_free (handler);
             }
         }
       g_list_free (glist);
@@ -292,9 +330,12 @@ static const gchar *vmaid_xpm[] = {
   select = gtk_tree_view_get_selection (GTK_TREE_VIEW (tview));
   gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
   g_signal_connect (G_OBJECT (select), "changed",
-                                G_CALLBACK (version_dialog_changed), button);
+                            G_CALLBACK (version_dialog_changed), button);
   g_signal_connect (G_OBJECT (store), "row-deleted",
-                                G_CALLBACK (version_dialog_row_deleted), NULL);
+                            G_CALLBACK (version_dialog_row_deleted), NULL);
+  g_signal_connect (G_OBJECT (tview), "button-press-event",
+                            G_CALLBACK (version_dialog_button_press), NULL);
+  gtk_widget_add_events (tview, GDK_BUTTON_PRESS_MASK);
   g_object_unref (G_OBJECT (store));
   /* ja:スクロールウインドウ */
   scroll = gtk_scrolled_window_new (NULL, NULL);
@@ -316,12 +357,6 @@ static const gchar *vmaid_xpm[] = {
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox,
                                                 gtk_label_new (_("Codecs")));
 
-  /* ja:ボタン */
-  button = gtk_button_new_with_label (_("OK"));
-  g_signal_connect_swapped (G_OBJECT (button), "clicked",
-                        G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-
   /* ja:フレームとボックス */
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
@@ -337,16 +372,11 @@ static const gchar *vmaid_xpm[] = {
   gtk_box_pack_start (GTK_BOX (hbox1), hbox0, TRUE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox1, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), notebook, TRUE, TRUE, 0);
-  hbox0 = gtk_hbox_new (FALSE, SPACING);
-  gtk_box_pack_end (GTK_BOX (hbox0), button, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox0, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (dialog), vbox);
+  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), vbox);
 
   /* ja:表示 */
-  gtk_widget_grab_focus (button);
+  gtk_widget_show_all (vbox);
 
-  gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, TRUE, FALSE);
-  gtk_grab_add (dialog);
-  gtk_widget_show_all (dialog);
-  gtk_main ();
+  gtk_dialog_run (GTK_DIALOG (dialog));
+  gtk_widget_destroy (dialog);
 }
